@@ -154,6 +154,39 @@ class Crp:
 
 
 
+    def getTotalSpentLMonth(self,train_df,dateFlag_sep,df_matrix):
+        """
+        Params:
+        -----------------
+        Output:
+        
+        
+        """
+
+        total_spent_last_month_sep = dateFlag_sep - pd.DateOffset(months = 1)
+        
+        print('Last Month Money spent:',total_spent_last_month_sep)
+        
+        last_month_df = train_df[(train_df.order_date >= total_spent_last_month_sep - pd.DateOffset(months = 1)) & (train_df.order_date <= total_spent_last_month_sep)]
+        
+        last_month_spent = last_month_df.groupby('customerid').agg({'totalprice':'sum'}).reset_index()
+        
+        df_matrix = pd.merge(df_matrix,last_month_spent,on='customerid',how = 'left')
+        
+        
+        
+        df_matrix = df_matrix.fillna(0)
+        
+        df_matrix = df_matrix.rename(columns = {'totalprice':'Last_Month_Total_Spent'})
+        
+        
+        
+        output = df_matrix
+        
+        return output
+
+
+# ----------------------------------------------------------------------------------
 
     def getFeaturesMatrix(self,train_df,org_df,timeFlag,items_dataset):
         """
@@ -175,15 +208,17 @@ class Crp:
 
         grp_dict = {'order_date':'max','id':'count','totalprice':'sum','buyeracceptsmarketing':'max','billingaddresscountrycode':'unique'}
 
-        df_matrix = gb.agg(d).rename(columns={'id':'num_orders'})
+        df_matrix = grp.agg(grp_dict).rename(columns={'id':'num_orders','totalprice':'TotalSpent'})
 
         df_matrix = self.getRecency(last_orders,dateFlag_sep)
 
         df_matrix = self.getLastOrderValue(df_matrix,train_df)
 
+        df_matrix = self.getTotalSpentLMonth(train_df,dateFlag_sep,df_matrix)
+
 
         
-        output = df_matrix 
+        output = [df_matrix]
         
         return output
 
